@@ -52,6 +52,7 @@ from .checks.raster import RasterRangeCheck
 from .checks.raster import RasterSquareCellsCheck
 from .checks.timeseries import TimeseriesIncreasingCheck
 from .checks.timeseries import TimeseriesRowCheck
+from .checks.timeseries import TimeseriesStartsAtZeroCheck
 from .checks.timeseries import TimeseriesTimestepCheck
 from .checks.timeseries import TimeseriesValueCheck
 from .threedi_model import models
@@ -810,6 +811,12 @@ CHECKS += [
             "v2_exchange_line.the_geom is far (> 500 m) from its corresponding channel"
         ),
     ),
+    RangeCheck(
+        error_code=265,
+        column=models.ExchangeLine.exchange_level,
+        min_value=-9998.0,
+        max_value=8848.0,
+    ),
 ]
 
 ## 027x: Potential breaches
@@ -892,6 +899,19 @@ CHECKS += [
         column=models.PotentialBreach.the_geom,
         min_distance=TOLERANCE_M,
     ),
+    RangeCheck(
+        error_code=276,
+        column=models.PotentialBreach.exchange_level,
+        min_value=-9998.0,
+        max_value=8848.0,
+    ),
+    RangeCheck(
+        error_code=277,
+        column=models.PotentialBreach.maximum_breach_depth,
+        min_value=0.0,
+        max_value=100.0,
+        left_inclusive=False,
+    ),
 ]
 
 ## 030x: SETTINGS
@@ -2042,6 +2062,13 @@ CHECKS += [
         models.Lateral2D.timeseries,
     ]
 ]
+CHECKS += [
+    TimeseriesStartsAtZeroCheck(col, error_code=1204)
+    for col in [
+        models.BoundaryCondition1D.timeseries,
+        models.BoundaryConditions2D.timeseries,
+    ]
+]
 
 ## 122x Structure controls
 
