@@ -1,44 +1,44 @@
 from .checks.base import BaseCheck
 from .checks.base import CheckLevel
+from .checks.raster import LocalContext
+from .checks.raster import ServerContext
 from .config import Config
 from .schema import ModelSchema
 from .threedi_database import ThreediDatabase
-from pathlib import Path
+from typing import Dict
 from typing import Iterator
 from typing import NamedTuple
 from typing import Optional
-from typing import Set
 from typing import Tuple
 
 
 __all__ = ["ThreediModelChecker"]
 
 
-class Context:
-    def __init__(
-        self,
-        available_rasters: Optional[Set] = None,
-        base_path: Optional[Path] = None,
-    ):
-        self.available_rasters = available_rasters
-        self.base_path = base_path
-
-
 class ThreediModelChecker:
-    def __init__(self, threedi_db: ThreediDatabase, context: Optional[Context] = None):
+    def __init__(self, threedi_db: ThreediDatabase, context: Optional[Dict] = None):
         """Initialize the model checker.
 
         Optionally, supply the context of the model check:
-        - "available_rasters": a set of raster options that are available
-        - "base_path": file presence is checked relative to this path
+
+        - "context_type": "local" or "server", default "local"
+        - "raster_interface": a threedi_modelchecker.interfaces.RasterInterface subclass
+        - "base_path": (only local) path where to look for rasters (defaults to the db's directory)
+        - "available_rasters": (only server) a dict of raster_option -> raster url
         """
         self.db = threedi_db
         self.schema = ModelSchema(self.db)
         self.schema.validate_schema()
         self.config = Config(self.models)
-        self.context = Context(**(context or {}))
-        if not self.context.base_path:
-            self.context.base_path = self.db.base_path
+        context = {} if context is None else context.copy()
+        context_type = context.pop("context_type", "local")
+        if context_type == "local":
+            context.setdefault("base_path", self.db.base_path)
+            self.context = LocalContext(**context)
+        elif context_type == "server":
+            self.context = ServerContext(**context)
+        else:
+            raise ValueError(f"Unknown context_type '{context_type}'")
 
     @property
     def models(self):
